@@ -3,22 +3,12 @@
 import json
 import pathlib
 import typing as t
-
+import importlib
 from ruamel.yaml import YAML
 from json2html import *  # noqa F403
 
-from .cpu_info import query_cpu, print_cpu_info  # noqa F401
-from .gpu_info import query_gpus, print_gpus_info  # noqa F401
-from .hdd_info import print_hdd_info, query_hdd  # noqa F401
-from .host_info import query_host, print_host_info  # noqa F401
-from .network_info import query_network, print_network_info  # noqa F401
-from .os_info import query_os, print_os_info  # noqa F401
-from .ram_info import query_ram, print_ram_info  # noqa F401
-from .software_info import query_software, print_software_info  # noqa F401
-from .swap_info import query_swap, print_swap_info  # noqa F401
 
-
-def query_and_export(query_scope: list,
+def query_and_export(query_scope: set,
                      verbose: bool,
                      export_format: str,
                      generate_html_table: bool,
@@ -31,8 +21,10 @@ def query_and_export(query_scope: list,
         export(info, export_format, generate_html_table, output)
 
 
-def query(query_scope: list, verbose: bool, **kwargs) -> t.Any:
-    """Wrap around selected system query functions."""
+def query(query_scope: set, verbose: bool, **kwargs) -> t.Any:
+    """
+    Wrap around selected system query functions.
+    """
     info = {'cpu': {},
             'gpus': {},
             'ram': {},
@@ -42,22 +34,25 @@ def query(query_scope: list, verbose: bool, **kwargs) -> t.Any:
             'swap': {},
             'network': {},
             'software': {}}
-    if query_scope == ['all']:
-        query_scope = ['host', 'os', 'network', 'cpu', 'gpus', 'ram', 'hdd', 'swap', 'software']
+    if query_scope == {'all'}:
+        query_scope = ['host', 'os', 'swap', 'network', 'cpu', 'gpus', 'ram', 'hdd', 'software']
 
     for query in query_scope:
-        get_info = f'query_{query}'
-        query_info = globals()[get_info]()
+        querier_class = getattr(importlib.import_module(f'system_intelligence.{query}_info'), f'{query.capitalize()}Info')
+        instance = querier_class()
+        query_info = getattr(instance, f'query_{query}')()
         info[query] = query_info
+
         if verbose:
-            print_info = f'print_{query}_info'
-            globals()[print_info](query_info)
+            getattr(instance, f'print_{query}_info')(query_info)
 
     return info
 
 
 def export(info, export_format: str, generate_html_table: bool, export_target: t.Any):
-    """Export information obtained by system query to a specified format."""
+    """
+    Export information obtained by system query to a specified format.
+    """
     if export_format == 'json':
         with open(str(export_target), 'w', encoding='utf-8') as json_file:
             json.dump(info, json_file, indent=2, ensure_ascii=False)
@@ -71,8 +66,8 @@ def export(info, export_format: str, generate_html_table: bool, export_target: t
         raise NotImplementedError(f'format={export_format} target={export_target}')
     # write HTML Table
     if generate_html_table:
-        html_output_name = f'{str(export_target).split(".")[0]}.html'
-        with open(str(html_output_name), 'w', encoding='utf-8') as html_file:
+        html_output_name = f'{export_target}.html' if not str(export_target).endswith('.html') else export_target
+        with open(html_output_name, 'w', encoding='utf-8') as html_file:
             json_formatted = json.dumps(info, indent=2, ensure_ascii=False)
             html_table = json2html.convert(json=json_formatted,  # noqa F405
                                            table_attributes="id=\"system-intelligence\""
